AuthorizationStateWaitEmailCode class final

AuthorizationStateWaitEmailCode (authorizationStateWaitEmailCode) - child of AuthorizationState

TDLib needs the user's authentication code sent to an email address to authorize. Call checkAuthenticationEmailCode to provide the code.

  • allowAppleId: True, if authorization through Apple authorizationStateWaitEmailCode is allowed.
  • allowGoogleId: True, if authorization through Google authorizationStateWaitEmailCode is allowed.
  • codeInfo: Information about the sent authentication code.
  • emailAddressResetState: Reset state of the email address; may be null if the email address can't be reset (optional).
Inheritance

Constructors

AuthorizationStateWaitEmailCode({required bool allowAppleId, required bool allowGoogleId, required EmailAddressAuthenticationCodeInfo codeInfo, EmailAddressResetState? emailAddressResetState, dynamic extra, int? clientId})
AuthorizationStateWaitEmailCode (authorizationStateWaitEmailCode) - child of AuthorizationState
const
AuthorizationStateWaitEmailCode.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

allowAppleId → bool
True, if authorization through Apple authorizationStateWaitEmailCode is allowed
final
allowGoogleId → bool
True, if authorization through Google authorizationStateWaitEmailCode is allowed
final
clientId → int?
clientId client identifier
final
codeInfo → EmailAddressAuthenticationCodeInfo
Information about the sent authentication code
final
currentObjectId → String
TDLib object type for current class instance
no setteroverride
emailAddressResetState → EmailAddressResetState?
Reset state of the email address; may be null if the email address can't be reset
final
extra → dynamic
extra callback sign
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? allowAppleId, bool? allowGoogleId, EmailAddressAuthenticationCodeInfo? codeInfo, EmailAddressResetState? emailAddressResetState, dynamic extra, int? clientId}) → AuthorizationStateWaitEmailCode
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() → String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type