ChatFolderInfo class final

ChatFolderInfo (chatFolderInfo) - basic class

Contains basic information about a chat folder.

  • id: Unique chat folder identifier.
  • title: The title of the folder; 1-12 characters without line feeds.
  • icon: The chosen or default icon for the chat folder.
  • colorId: The identifier of the chosen color for the chat folder icon; from -1 to 6. If -1, then color is disabled.
  • isShareable: True, if at least one link has been created for the folder.
  • hasMyInviteLinks: True, if the chat folder has invite links created by the current user.
Inheritance

Constructors

ChatFolderInfo({required int id, required String title, required ChatFolderIcon icon, required int colorId, required bool isShareable, required bool hasMyInviteLinks, dynamic extra, int? clientId})
ChatFolderInfo (chatFolderInfo) - basic class
const
ChatFolderInfo.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId int?
clientId client identifier
final
colorId int
The identifier of the chosen color for the chat folder icon; from -1 to 6. If -1, then color is disabled
final
currentObjectId String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
hashCode int
The hash code for this object.
no setterinherited
True, if the chat folder has invite links created by the current user
final
icon ChatFolderIcon
The chosen or default icon for the chat folder
final
id int
Unique chat folder identifier
final
isShareable bool
True, if at least one link has been created for the folder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The title of the folder; 1-12 characters without line feeds
final

Methods

copyWith({int? id, String? title, ChatFolderIcon? icon, int? colorId, bool? isShareable, bool? hasMyInviteLinks, dynamic extra, int? clientId}) ChatFolderInfo
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type