GiveawayParticipantStatusAdministrator class final

GiveawayParticipantStatusAdministrator (giveawayParticipantStatusAdministrator) - child of GiveawayParticipantStatus

The user can't participate in the giveaway, because they are an administrator in one of the chats that created the giveaway.

  • chatId: Identifier of the chat administered by the user.
Inheritance

Constructors

GiveawayParticipantStatusAdministrator({required int chatId})
GiveawayParticipantStatusAdministrator (giveawayParticipantStatusAdministrator) - child of GiveawayParticipantStatus
const
GiveawayParticipantStatusAdministrator.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

chatId int
Identifier of the chat administered by the user
final
clientId int?
Client ID, from which this object was received
no setterinherited
currentObjectId String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) GiveawayParticipantStatusAdministrator
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type