InputMessageForwarded constructor
const
InputMessageForwarded({
- required int fromChatId,
- required int messageId,
- MessageCopyOptions? copyOptions,
InputMessageForwarded (inputMessageForwarded) - child of InputMessageContent
A forwarded message.
fromChatId: Identifier for the chat this forwarded message came from.messageId: Identifier of the message to forward. A message can be forwarded only if messageProperties.can_be_forwarded.inGameShare: True, if a game message is being shared from a launched game; applies only to game messages.copyOptions: Options to be used to copy content of the message without reference to the original sender; pass null to forward the message as usual (optional).
Implementation
const InputMessageForwarded({
required this.fromChatId,
required this.messageId,
required this.inGameShare,
this.copyOptions,
});