InternalLinkTypeGame class final

InternalLinkTypeGame (internalLinkTypeGame) - child of InternalLinkType

The link is a link to a game. Call searchPublicChat with the given bot username, check that the user is a bot,. ask the current user to select a chat to send the game, and then call sendMessage with inputMessageGame.

Inheritance

Constructors

InternalLinkTypeGame({required String botUsername, required String gameShortName, dynamic extra, int? clientId})
InternalLinkTypeGame (internalLinkTypeGame) - child of InternalLinkType
const
InternalLinkTypeGame.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

botUsername String
Username of the bot that owns the game
final
clientId int?
clientId client identifier
final
currentObjectId String
TDLib object type for current class instance
no setteroverride
extra → dynamic
extra callback sign
final
gameShortName String
Short name of the game
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? botUsername, String? gameShortName, dynamic extra, int? clientId}) InternalLinkTypeGame
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type