LinkPreviewTypeStory class final

LinkPreviewTypeStory (linkPreviewTypeStory) - child of LinkPreviewType

The link is a link to a story. Link preview description is unavailable.

Inheritance

Constructors

LinkPreviewTypeStory({required int storySenderChatId, required int storyId})
LinkPreviewTypeStory (linkPreviewTypeStory) - child of LinkPreviewType
const
LinkPreviewTypeStory.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId int?
Client ID, from which this object was received
no setterinherited
currentObjectId String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
Story identifier
final
storySenderChatId int
The identifier of the chat that posted the story
final

Methods

copyWith({int? storySenderChatId, int? storyId}) LinkPreviewTypeStory
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type