MessageCalendarDay class final

MessageCalendarDay (messageCalendarDay) - basic class

Contains information about found messages sent on a specific day.

  • totalCount: Total number of found messages sent on the day.
  • message: First message sent on the day.
Inheritance

Constructors

MessageCalendarDay({required int totalCount, required Message message})
MessageCalendarDay (messageCalendarDay) - basic class
const
MessageCalendarDay.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId int?
Client ID, from which this object was received
no setterinherited
currentObjectId String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
message Message
First message sent on the day
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
Total number of found messages sent on the day
final

Methods

copyWith({int? totalCount, Message? message}) MessageCalendarDay
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type