MessageGiveawayCreated class final

MessageGiveawayCreated (messageGiveawayCreated) - child of MessageContent

A giveaway was created for the chat. Use telegramPaymentPurposePremiumGiveaway, storePaymentPurposePremiumGiveaway, telegramPaymentPurposeStarGiveaway, or storePaymentPurposeStarGiveaway to create a giveaway.

  • starCount: Number of Telegram Stars that will be shared by winners of the giveaway; 0 for Telegram Premium giveaways.
Inheritance

Constructors

MessageGiveawayCreated({required int starCount})
MessageGiveawayCreated (messageGiveawayCreated) - child of MessageContent
const
MessageGiveawayCreated.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId int?
Client ID, from which this object was received
no setterinherited
currentObjectId String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
Number of Telegram Stars that will be shared by winners of the giveaway; 0 for Telegram Premium giveaways
final

Methods

copyWith({int? starCount}) MessageGiveawayCreated
Copy model with modified properties.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type