SearchMessagesFilterUnreadMention class final

SearchMessagesFilterUnreadMention (searchMessagesFilterUnreadMention) - child of SearchMessagesFilter

Returns only messages with unread mentions of the current user, or messages that are replies to their messages. When using this filter the results can't be additionally filtered by a query, a message thread or by the sending user.

Inheritance

Constructors

SearchMessagesFilterUnreadMention()
SearchMessagesFilterUnreadMention (searchMessagesFilterUnreadMention) - child of SearchMessagesFilter
const
SearchMessagesFilterUnreadMention.fromJson(Map<String, dynamic> json)
Parse from a json
factory

Properties

clientId int?
Client ID, from which this object was received
no setterinherited
currentObjectId String
TDLib object type for current class instance
no setteroverride
extra → dynamic
A sign from TDLib update
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() SearchMessagesFilterUnreadMention
Copy instance with no modifications.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type