SendCallDebugInformation class final
SendCallDebugInformation (sendCallDebugInformation) - TDLib function
Sends debug information for a call to Telegram servers.
- callId: Call identifier.
- debugInformation: Debug information in application-specific format.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SendCallDebugInformation
Constructors
- SendCallDebugInformation({required int callId, required String debugInformation})
-
SendCallDebugInformation (sendCallDebugInformation) - TDLib function
const
Properties
- callId → int
-
Call identifier
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- debugInformation → String
-
Debug information in application-specific format
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? callId, String? debugInformation}) → SendCallDebugInformation - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type