SendPhoneNumberFirebaseSms class final

SendPhoneNumberFirebaseSms (sendPhoneNumberFirebaseSms) - TDLib function

Sends Firebase Authentication SMS to the specified phone number. Works only when received a code of the type authenticationCodeTypeFirebaseAndroid or authenticationCodeTypeFirebaseIos.

  • token: Play Integrity API or SafetyNet Attestation API token for the Android application, or secret from push notification for the iOS application.

Ok is returned on completion.

Inheritance

Constructors

SendPhoneNumberFirebaseSms({required String token})
SendPhoneNumberFirebaseSms (sendPhoneNumberFirebaseSms) - TDLib function
const

Properties

currentObjectId String
TDLib object type for current class instance
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Play Integrity API or SafetyNet Attestation API token for the Android application, or secret from push notification for the iOS application
final

Methods

copyWith({String? token}) SendPhoneNumberFirebaseSms
Copy model with modified properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([dynamic extra]) Map<String, dynamic>
Convert model to TDLib JSON format
override
toString() String
Convert model to TDLib JSON format, encoded into String.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultObjectId → const String
TDLib object type