StickerFullTypeRegular class final
StickerFullTypeRegular (stickerFullTypeRegular) - child of StickerFullType
The sticker is a regular sticker.
- premiumAnimation: Premium animation of the sticker; may be null. If present, only Telegram Premium users can use the sticker (optional).
- Inheritance
-
- Object
- TdObject
- StickerFullType
- StickerFullTypeRegular
Constructors
- StickerFullTypeRegular({})
-
StickerFullTypeRegular (stickerFullTypeRegular) - child of StickerFullType
const
-
StickerFullTypeRegular.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Premium animation of the sticker; may be null. If present, only Telegram Premium users can use the sticker
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{}) → StickerFullTypeRegular -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type