ChangeStickerSet class final
ChangeStickerSet (changeStickerSet) - TDLib function
Installs/uninstalls or activates/archives a sticker set.
- setId: Identifier of the sticker set.
- isInstalled: The new value of is_installed.
- isArchived: The new value of is_archived. A sticker set can't be installed and archived simultaneously.
Ok is returned on completion.
- Inheritance
-
- Object
- TdFunction
- ChangeStickerSet
Constructors
- ChangeStickerSet({required int setId, required bool isInstalled, required bool isArchived})
-
ChangeStickerSet (changeStickerSet) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isArchived → bool
-
The new value of is_archived. A sticker set can't be installed and archived simultaneously
final
- isInstalled → bool
-
The new value of is_installed
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setId → int
-
Identifier of the sticker set
final
Methods
-
copyWith(
{int? setId, bool? isInstalled, bool? isArchived}) → ChangeStickerSet - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type