ChatEventSlowModeDelayChanged class final
ChatEventSlowModeDelayChanged (chatEventSlowModeDelayChanged) - child of ChatEventAction
The slow_mode_delay setting of a supergroup was changed.
- oldSlowModeDelay: Previous value of slow_mode_delay, in seconds.
- newSlowModeDelay: New value of slow_mode_delay, in seconds.
- Inheritance
-
- Object
- TdObject
- ChatEventAction
- ChatEventSlowModeDelayChanged
Constructors
- ChatEventSlowModeDelayChanged({required int oldSlowModeDelay, required int newSlowModeDelay})
-
ChatEventSlowModeDelayChanged (chatEventSlowModeDelayChanged) - child of ChatEventAction
const
-
ChatEventSlowModeDelayChanged.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- newSlowModeDelay → int
-
New value of slow_mode_delay, in seconds
final
- oldSlowModeDelay → int
-
Previous value of slow_mode_delay, in seconds
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? oldSlowModeDelay, int? newSlowModeDelay}) → ChatEventSlowModeDelayChanged -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type