ChatMemberStatusAdministrator class final
ChatMemberStatusAdministrator (chatMemberStatusAdministrator) - child of ChatMemberStatus
The user is a member of the chat and has some additional privileges. In basic groups, administrators can edit and delete messages sent by others, add new members, ban unprivileged members, and manage video chats.. In supergroups and channels, there are more detailed options for administrator privileges.
- customTitle: A custom title of the administrator; 0-16 characters without emoji; applicable to supergroups only.
- canBeEdited: True, if the current user can edit the administrator privileges for the called user.
- rights: Rights of the administrator.
- Inheritance
-
- Object
- TdObject
- ChatMemberStatus
- ChatMemberStatusAdministrator
Constructors
- ChatMemberStatusAdministrator({required String customTitle, required bool canBeEdited, required ChatAdministratorRights rights})
-
ChatMemberStatusAdministrator (chatMemberStatusAdministrator) - child of ChatMemberStatus
const
-
ChatMemberStatusAdministrator.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- canBeEdited → bool
-
True, if the current user can edit the administrator privileges for the called user
final
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- customTitle → String
-
A custom title of the administrator; 0-16 characters without emoji; applicable to supergroups only
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- rights → ChatAdministratorRights
-
Rights of the administrator
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? customTitle, bool? canBeEdited, ChatAdministratorRights? rights}) → ChatMemberStatusAdministrator -
Copy model with modified properties.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type