CheckStickerSetName class final
CheckStickerSetName (checkStickerSetName) - TDLib function
Checks whether a name can be used for a new sticker set.
- name: Name to be checked.
CheckStickerSetNameResult is returned on completion.
- Inheritance
-
- Object
- TdFunction
- CheckStickerSetName
Constructors
- CheckStickerSetName({required String name})
-
CheckStickerSetName (checkStickerSetName) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Name to be checked
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? name}) → CheckStickerSetName - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type