EditChatFolderInviteLink class final
EditChatFolderInviteLink (editChatFolderInviteLink) - TDLib function
Edits an invite link for a chat folder.
- chatFolderId: Chat folder identifier.
- inviteLink: Invite link to be edited.
- name: New name of the link; 0-32 characters.
- chatIds: New identifiers of chats to be accessible by the invite link. Use getChatsForChatFolderInviteLink to get suitable chats. Basic groups will be automatically converted to supergroups before link editing.
ChatFolderInviteLink is returned on completion.
- Inheritance
-
- Object
- TdFunction
- EditChatFolderInviteLink
Constructors
Properties
- chatFolderId → int
-
Chat folder identifier
final
-
chatIds
→ List<
int> -
New identifiers of chats to be accessible by the invite link. Use getChatsForChatFolderInviteLink to get suitable chats. Basic groups will be automatically converted to supergroups before link editing
final
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviteLink → String
-
Invite link to be edited
final
- name → String
-
New name of the link; 0-32 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatFolderId, String? inviteLink, String? name, List< int> ? chatIds}) → EditChatFolderInviteLink - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type