GetEmojiSuggestionsUrl class final
GetEmojiSuggestionsUrl (getEmojiSuggestionsUrl) - TDLib function
Returns an HTTP URL which can be used to automatically log in to the translation platform and suggest new emoji replacements. The URL will be valid for 30 seconds after generation.
- languageCode: Language code for which the emoji replacements will be suggested.
HttpUrl is returned on completion.
- Inheritance
-
- Object
- TdFunction
- GetEmojiSuggestionsUrl
Constructors
- GetEmojiSuggestionsUrl({required String languageCode})
-
GetEmojiSuggestionsUrl (getEmojiSuggestionsUrl) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String
-
Language code for which the emoji replacements will be suggested
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? languageCode}) → GetEmojiSuggestionsUrl - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type