GroupCallParticipantVideoInfo class final
GroupCallParticipantVideoInfo (groupCallParticipantVideoInfo) - basic class
Contains information about a group call participant's video channel.
- sourceGroups: List of synchronization source groups of the video.
- endpointId: Video channel endpoint identifier.
- isPaused: True, if the video is paused. This flag needs to be ignored, if new video frames are received.
Constructors
-
GroupCallParticipantVideoInfo({required List<
GroupCallVideoSourceGroup> sourceGroups, required String endpointId, required bool isPaused}) -
GroupCallParticipantVideoInfo (groupCallParticipantVideoInfo) - basic class
const
-
GroupCallParticipantVideoInfo.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- endpointId → String
-
Video channel endpoint identifier
final
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPaused → bool
-
True, if the video is paused. This flag needs to be ignored, if new video frames are received
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceGroups
→ List<
GroupCallVideoSourceGroup> -
List of synchronization source groups of the video
final
Methods
-
copyWith(
{List< GroupCallVideoSourceGroup> ? sourceGroups, String? endpointId, bool? isPaused}) → GroupCallParticipantVideoInfo - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type