Photo class final
Photo (photo) - basic class
Describes a photo.
- hasStickers: True, if stickers were added to the photo. The list of corresponding sticker sets can be received using getAttachedStickerSets.
- minithumbnail: Photo minithumbnail; may be null (optional).
- sizes: Available variants of the photo, in different sizes.
Constructors
-
Photo({required bool hasStickers, Minithumbnail? minithumbnail, required List<
PhotoSize> sizes}) -
Photo (photo) - basic class
const
-
Photo.fromJson(Map<
String, dynamic> json) -
Parse from a json
factory
Properties
- clientId → int?
-
Client ID, from which this object was received
no setterinherited
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- extra → dynamic
-
A sign from TDLib update
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasStickers → bool
-
True, if stickers were added to the photo. The list of corresponding sticker sets can be received using getAttachedStickerSets
final
- minithumbnail → Minithumbnail?
-
Photo minithumbnail; may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sizes
→ List<
PhotoSize> -
Available variants of the photo, in different sizes
final
Methods
-
copyWith(
{bool? hasStickers, Minithumbnail? minithumbnail, List< PhotoSize> ? sizes}) → Photo - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type