SearchStickerSets class final
SearchStickerSets (searchStickerSets) - TDLib function
Searches for sticker sets by looking for specified query in their title and name. Excludes installed sticker sets from the results.
- stickerType: Type of the sticker sets to return.
- query: Query to search for.
StickerSets is returned on completion.
- Inheritance
-
- Object
- TdFunction
- SearchStickerSets
Constructors
- SearchStickerSets({required StickerType stickerType, required String query})
-
SearchStickerSets (searchStickerSets) - TDLib function
const
Properties
- currentObjectId → String
-
TDLib object type for current class instance
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → String
-
Query to search for
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerType → StickerType
-
Type of the sticker sets to return
final
Methods
-
copyWith(
{StickerType? stickerType, String? query}) → SearchStickerSets - Copy model with modified properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
[dynamic extra]) → Map< String, dynamic> -
Convert model to TDLib JSON format
override
-
toString(
) → String -
Convert model to TDLib JSON format, encoded into String.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultObjectId → const String
- TDLib object type